#' Height and gender for a stratified random sample from htpop
#' 
#' Height and gender for a stratified random sample of 160 women
#' and 40 men taken from the htpop population
#' @name htstrat
#' @docType data
#' @format \describe{
#'   \item{rn}{random number used to select the unit}
#'   \item{height}{height of person, cm}
#'   \item{gender}{factor with levels \code{F} (female) and \code{M} (male)}
#' }
#' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. 230--234 and
#'   442.
#' @export
NULL
